Builds a contingency table from two columns of a data frame and runs simple
correspondence analysis (MASS::corresp), returning row and column
coordinates and the inertia decomposition.
Arguments
- data
A data frame.
- row
<
tidy-select> The single row-factor column.- col
<
tidy-select> The single column-factor column.- nf
Number of dimensions to compute; must be smaller than both the number of rows and the number of columns of the table.
Value
An object of class mv_corresp: a list with components
row_coord (tibble with row and Dim1...), col_coord (tibble with
col and Dim1...), inertia (tibble with dimension, inertia,
prop, cum), and meta.